@@ -3,8 +3,7 @@ from __future__ import annotations
 from typing import Optional, Union
 
 from osaft import log
-from osaft.core.backgroundfields import WaveTypes, WrongWaveTypeError
-from osaft.core.basecomposite import BaseSphereFrequencyComposite
+from osaft.core.backgroundfields import WaveType, WrongWaveTypeError
 from osaft.core.frequency import Frequency
 from osaft.core.functions import pi, sin, sqrt
 from osaft.core.geometries import Sphere
@@ -14,7 +13,7 @@ from osaft.solutions.base_arf import BaseARF
 from osaft.solutions.Doinikov1994Compressible.scattering import ScatteringField
 
 
-class ARF(ScatteringField, BaseARF, BaseSphereFrequencyComposite):
+class ARF(ScatteringField, BaseARF):
     """Base class for Doinikov (viscous fluid-viscous sphere; 1994)
 
     .. note::
@@ -61,7 +60,7 @@ class ARF(ScatteringField, BaseARF, BaseSphereFrequencyComposite):
         rho_f: float, c_f: float,
         eta_f: float, zeta_f: float,
         p_0: float,
-        wave_type: WaveTypes,
+        wave_type: WaveType,
         position: Optional[float] = None,
         small_viscous_boundary_layer: bool = False,
         large_viscous_boundary_layer: bool = False,
@@ -72,12 +71,11 @@ class ARF(ScatteringField, BaseARF, BaseSphereFrequencyComposite):
         """
 
         # init of parent class
-        BaseSphereFrequencyComposite.__init__(self, frequency, radius)
-        ScatteringField.__init__(
-            self, frequency, radius,
-            rho_s, c_s, eta_s, zeta_s,
-            rho_f, c_f, eta_f, zeta_f,
-            p_0, wave_type, position, N_max,
+        super().__init__(
+            frequency=frequency, radius=radius,
+            rho_s=rho_s, c_s=c_s, eta_s=eta_s, zeta_s=zeta_s,
+            rho_f=rho_f, c_f=c_f, eta_f=eta_f, zeta_f=zeta_f,
+            p_0=p_0, wave_type=wave_type, position=position, N_max=N_max,
         )
 
         # independent variables
@@ -100,11 +98,6 @@ class ARF(ScatteringField, BaseARF, BaseSphereFrequencyComposite):
         )
 
         # Dependent variables
-        self._norm_delta = ActiveVariable(
-            self._compute_norm_delta,
-            'normalized boundary layer '
-            'thickness',
-        )
         self._mu = ActiveVariable(
             self._compute_mu,
             '(density * viscosity) ratio',
@@ -158,7 +151,6 @@ class ARF(ScatteringField, BaseARF, BaseSphereFrequencyComposite):
         self._g5.is_computed_by(self._eta_t)
         self._g6.is_computed_by(self._eta_t)
         self._g7.is_computed_by(self._g6)
-        self._norm_delta.is_computed_by(self.fluid._delta, self.sphere._R_0)
         self._kappa_t.is_computed_by(
             self.fluid._rho_f, self.fluid._c_f, self.scatterer._rho_f,
             self.scatterer._c_f,
@@ -273,15 +265,18 @@ class ARF(ScatteringField, BaseARF, BaseSphereFrequencyComposite):
 
         It logs the current values of :attr:`x` and :attr:`x_v`.
 
-        :raises ValueError: Non supported :attr:`~osaft.solutions.\
-Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
+        :raises WrongWaveTypeError: if wrong :attr:`wave_type`
         """
+
+        # Check boundary layer
         self._check_boundary_layer(
             self.small_viscous_boundary_layer,
             self.large_viscous_boundary_layer,
         )
-        if not isinstance(self.wave_type, WaveTypes):
-            raise WrongWaveTypeError
+
+        # Checking Wave Type
+        self.check_wave_type()
+        # Cases
         if self.small_viscous_boundary_layer:
             return self._arf_small_particle_small_delta()
         else:
@@ -292,31 +287,30 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
     # -------------------------------------------------------------------------
 
     def _arf_small_particle_large_delta(self) -> float:
-        """ Eq. 7.1 for WaveTypes.TRAVELLING; Eq. 7.8 for WaveTypes.STANDING
+        """ Eq. 7.1 for WaveType.TRAVELLING; Eq. 7.8 for WaveType.STANDING
         """
         log.info(
             f'kappa_t << 1 : {self.kappa_t:.3e} << 1\n'
             f'rho_f << rho_s : {self.rho_s:.3e} << {self.rho_s:.3e}\n',
         )
 
-        if self.wave_type == WaveTypes.TRAVELLING:
+        if self.wave_type == WaveType.TRAVELLING:
             out = 5 - 2 * self.kappa_t - 8 * self.f1
 
             out *= 1 / 6 * self.norm_delta ** 2
         else:
             out = self.G * self._standing_wave_contribution()
-
         out *= pi * self.field.abs_A_squared * self.rho_f * self.x_0**3
         return out
 
     def _arf_small_particle_small_delta(self) -> float:
-        """ Eq. 6.1 for WaveTypes.TRAVELLING
+        """ Eq. 6.1 for WaveType.TRAVELLING
         """
         log.info(
             f'kappa_t << 1 : {self.kappa_t:.3e} << 1\n'
             f'mu << 1 : {self.mu:.3e} << 1\n',
         )
-        if self.wave_type == WaveTypes.TRAVELLING:
+        if self.wave_type == WaveType.TRAVELLING:
             out = (self.rho_s - self.rho_f) ** 2
             out /= (2 * self.rho_s + self.rho_f)**2 * (1 + self.mu)
 
@@ -324,7 +318,7 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
 
             out *= 6 * pi * self.rho_f * self.field.abs_A_squared
         else:
-            raise NotImplementedError(
+            raise WrongWaveTypeError(
                 'This solution is not implemented because Doinikov says '
                 'in 6.1.2 of the publication that this solution is '
                 'the same as Yosioka already computed.\n If you are '
@@ -596,16 +590,6 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
     def _compute_g7(self):
         return self.g6**2
 
-    @property
-    def norm_delta(self) -> float:
-        """ normalized viscous boundary thickness
-        :math:`\\tilde{\\delta}=\\frac{\\delta}{R_0}`
-        """
-        return self._norm_delta.value
-
-    def _compute_norm_delta(self):
-        return self.delta / self.R_0
-
     @property
     def mu(self) -> float:
         """ (density x viscosity) ratio
@@ -628,12 +612,6 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
     def _compute_kappa_t(self):
         return self.kappa_s / self.kappa_f
 
-    @property
-    def x_0(self) -> float:
-        """ Real part of :attr:`~.x`
-        """
-        return self.x.real
-
 
 if __name__ == '__main__':
     pass
