@@ -1,8 +1,9 @@
 import unittest
+from enum import auto
 
 import numpy as np
 
-from osaft import Gorkov1962, King1934, WaveTypes
+from osaft import Gorkov1962, King1934, WaveType
 from osaft.core.backgroundfields import WrongWaveTypeError
 from osaft.core.functions import pi, sin
 from osaft.tests.basetest_arf import HelperCompareARF
@@ -35,9 +36,9 @@ class TestARF(BaseKing):
 
     @property
     def Phi(self):
-        if self.wave_type == WaveTypes.TRAVELLING:
+        if self.wave_type == WaveType.TRAVELLING:
             return self.compute_Phi_traveling()
-        elif self.wave_type == WaveTypes.STANDING:
+        elif self.wave_type == WaveType.STANDING:
             return self.compute_Phi_standing()
 
     def compute_Phi_standing(self):
@@ -63,7 +64,7 @@ class TestARF(BaseKing):
         out -= self.G_n(n + 1, alpha) * self.F_n(n, alpha)
         return out
 
-    def HH_n(self, n):
+    def HH(self, n):
         out = self.cls.alpha**2
         if n == 1:
             out -= 3 * (1 - 1 / self.cls.rho_tilde)
@@ -75,21 +76,21 @@ class TestARF(BaseKing):
         return out
 
     def compute_general_ARF(self, n):
-        if self.wave_type == WaveTypes.TRAVELLING:
+        if self.wave_type == WaveType.TRAVELLING:
             return self.compute_traveling_general_ARF(n)
-        elif self.wave_type == WaveTypes.STANDING:
+        elif self.wave_type == WaveType.STANDING:
             return self.compute_standing_general_ARF(n)
 
     def compute_standing_general_ARF(self, n):
         alpha = self.cls.alpha
         # n = 0
         out = self.FFGG(0)
-        out /= self.HH_n(0)
+        out /= self.HH(0)
         out /= alpha
         # n = 1
         tmp = 2 / alpha**5
         tmp *= self.FFGG(1)
-        tmp /= self.HH_n(1)
+        tmp /= self.HH(1)
         tmp *= alpha**2 - 3 * (1 - 1 / self.cls.rho_tilde)
         out -= tmp
         # n > 1
@@ -97,7 +98,7 @@ class TestARF(BaseKing):
             tmp = (-1)**i
             tmp *= (i + 1) / alpha**(2 * i + 3)
             tmp *= self.FFGG(i)
-            tmp /= self.HH_n(i)
+            tmp /= self.HH(i)
             tmp *= alpha**2 - i * (i + 2)
 
             out += tmp
@@ -111,15 +112,15 @@ class TestARF(BaseKing):
     def compute_traveling_general_ARF(self, n):
         alpha = self.cls.alpha
         # n = 0
-        out = 1 / self.HH_n(0)
+        out = 1 / self.HH(0)
         # n = 1
-        tmp = 2 / self.HH_n(1)
+        tmp = 2 / self.HH(1)
         tmp *= (alpha**2 - 3 * (1 - 1 / self.cls.rho_tilde))**2
         tmp /= alpha**8
         out += tmp
         # n > 1
         for i in range(2, n):
-            tmp = (i + 1) / self.HH_n(i)
+            tmp = (i + 1) / self.HH(i)
             tmp *= (alpha**2 - i * (i + 2))**2
             tmp /= alpha**(4 * i + 4)
             out += tmp
@@ -141,7 +142,7 @@ class TestARF(BaseKing):
         dict_method = {}
         dict_method['FGFG'] = None
         dict_method['FFGG'] = None
-        dict_method['HH_n'] = None
+        dict_method['HH'] = None
 
         self._test_methods_n(dict_method)
 
@@ -160,13 +161,9 @@ class TestARF(BaseKing):
             )
 
     def test_NotImplemented_solution(self) -> None:
-        self.cls.small_particle_limit = False
-        self.cls.wave_type = 'random'
-
-        self.assertRaises(
-            WrongWaveTypeError,
-            self.cls.compute_arf,
-        )
+        WaveType.WRONGWAVETYPE = auto()
+        self.cls.wave_type = WaveType.WRONGWAVETYPE
+        self.assertRaises(WrongWaveTypeError, self.cls.compute_arf)
 
     def test_not_small_particle(self):
         # This method is not actually testing, only for coverage
